@@ -3,9 +3,10 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
                                l1_values = list(), l1_interactions = list(), l1_interactions_index = array(dim = 0), 
                                l2_values = list(), l2_interactions = list(), l2_interactions_index = array(dim = 0), 
                                numeric_index_in_X, numeric_index_in_Z){
+  
+  sol_tables <- list()
   if (length(X_assign) == 1 && length(Z_assign) == 1) coeff_table <- matrix(coeff_table, nrow = 1) # the case that there is only one intercept 
   n_sample <- nrow(samples_l2_param)
-  
   num_l1 <- length(X_assign)
   num_l2 <- length(Z_assign)
   est_matrix <- array(0 , dim = c(num_l1, num_l2, n_sample), dimnames = list(X_names, Z_names, NULL))
@@ -35,8 +36,9 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
     ggmean <- ggmean + n_c*gmean[[n_c]]
     
   }
-  cat(round(mean(ggmean), digits = 5), '\n')
-  print(as.table(matrix(round(quantile(ggmean, probs = c(0.025, 0.975)), digits = 5), nrow = 1, ncol = 2, dimnames = list('',c('2.5%','97.5%')))))
+  cat(round(mean(ggmean), digits = 4), '\n')
+  sol_tables[['Grand mean: \n']] <- as.table(matrix(round(quantile(ggmean, probs = c(0.025, 0.975)), digits = 4), nrow = 1, ncol = 2, dimnames = list('',c('2.5%','97.5%'))))
+  print(sol_tables[['Grand mean: \n']])
   
   # means by main effect in level 1 and 2 
   if (length(X_classes) != 0){
@@ -55,19 +57,20 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           est_l1mean <- est_l1mean + n_c*est_samples[[n_c]]
         }
-        means <- apply(est_l1mean, 1, median)
+        means <- apply(est_l1mean, 1, mean)
         quantile_025 <- apply(est_l1mean, 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
         quantile_975 <- apply(est_l1mean, 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
         table <- matrix(NA, nrow = length(means), ncol = 4)
         table[, 2] <- means
         table[, 3] <- pmin(quantile_025, quantile_975)
         table[, 4] <- pmax(quantile_025, quantile_975)
-        table <- round(table, digits = 5)
+        table <- round(table, digits = 4)
         table[, 1] <- attr(l1_matrix[[i]][[1]],'levels')
-        colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], 'median', '2.5%', '97.5%')
+        colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], 'mean', '2.5%', '97.5%')
         rownames(table) <- rep('', nrow(table))
         cat('\n')
         print(as.table(table))
+        sol_tables[['Table of means for factors at level 1: \n']] <- as.table(table)
       }
     }
   }
@@ -86,19 +89,20 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           est_l2mean <- est_l2mean + n_c*est_samples[[n_c]]
         }
-        means <- apply(est_l2mean, 1, median)
+        means <- apply(est_l2mean, 1, mean)
         quantile_025 <- apply(est_l2mean, 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
         quantile_975 <- apply(est_l2mean, 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
         table <- matrix(NA, nrow = length(means), ncol = 4)
         table[, 2] <- means
         table[, 3] <- pmin(quantile_025, quantile_975)
         table[, 4] <- pmax(quantile_025, quantile_975)
-        table <- round(table, digits = 5)
+        table <- round(table, digits = 4)
         table[, 1] <- attr(l2_matrix[[i]],'levels')
-        colnames(table) <- c(attr(Z_classes, 'names')[l2_factors[i]], 'median', '2.5%', '97.5%')
+        colnames(table) <- c(attr(Z_classes, 'names')[l2_factors[i]], 'mean', '2.5%', '97.5%')
         rownames(table) <- rep('', nrow(table))
         cat('\n')
         print(as.table(table))
+        sol_tables[['Table of means of for factors at level 2: \n']] <- as.table(table)
       }
     }
   }
@@ -117,22 +121,23 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
             est_l1l2mean <- est_l1l2mean + n_c*est_samples[[n_c]]
           }
           
-          means <- apply(est_l1l2mean, c(1,2), median)
+          means <- apply(est_l1l2mean, c(1,2), mean)
           quantile_025 <- apply(est_l1l2mean, c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
           quantile_975 <- apply(est_l1l2mean, c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
           table <- matrix(NA, nrow = nrow(l1_matrix[[i]][[1]]) * nrow(l2_matrix[[j]]), ncol = 5)
           for (k1 in 1:nrow(l1_matrix[[i]][[1]])){
             temp <- ((k1-1) * nrow(l2_matrix[[j]]) + 1):((k1-1) * nrow(l2_matrix[[j]]) + nrow(l2_matrix[[j]]))
-            table[temp, 3] <- round(means[k1,], digits = 5)
-            table[temp, 4] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-            table[temp, 5] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+            table[temp, 3] <- round(means[k1,], digits = 4)
+            table[temp, 4] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+            table[temp, 5] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
             table[temp, 1] <- rep(attr(l1_matrix[[i]][[1]],'levels')[k1], nrow(l2_matrix[[j]]))
             table[temp, 2] <- attr(l2_matrix[[j]],'levels')
           }
-          colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], attr(Z_classes, 'names')[l2_factors[j]], 'median', '2.5%', '97.5%')
+          colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], attr(Z_classes, 'names')[l2_factors[j]], 'mean', '2.5%', '97.5%')
           rownames(table) <- rep('', nrow(table))
           cat('\n')
           print(as.table(table)) 
+          sol_tables[['Table of means for interactions between level 1 and level 2 factors: \n']] <- as.table(table)
         }
       }          
     }    
@@ -160,17 +165,18 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
           est_l1inmean <- est_l1inmean + n_c*est_samples[[n_c]]
         }
         
-        means <- apply(est_l1inmean, 1, median)
+        means <- apply(est_l1inmean, 1, mean)
         quantile_025 <- apply(est_l1inmean, 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
         quantile_975 <- apply(est_l1inmean, 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
         table <- cbind(attr(l1_inter_matrix[[index]][[1]], 'levels'), 
-                       round(means, digits = 5), 
-                       pmin(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), 
-                       pmax(round(quantile_025, digits = 5), round(quantile_975, digits = 5)))
-        colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]]], 'median', '2.5%', '97.5%')
+                       round(means, digits = 4), 
+                       pmin(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), 
+                       pmax(round(quantile_025, digits = 4), round(quantile_975, digits = 4)))
+        colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]]], 'mean', '2.5%', '97.5%')
         rownames(table) <- rep('', nrow(table))
         cat('\n')
         print(as.table(table))
+        sol_tables[['Table of means for interactions at level 1: \n']] <- as.table(table)
         
         # print the interaction between this interaction and level 2 factors if there exists
         if (length(Z_classes) != 0){
@@ -186,24 +192,25 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
                 est_l1inl2mean <- est_l1inl2mean + n_c*est_samples[[n_c]]
               }
               
-              means <- apply(est_l1inl2mean, c(1,2), median)
+              means <- apply(est_l1inl2mean, c(1,2), mean)
               quantile_025 <- apply(est_l1inl2mean, c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
               quantile_975 <- apply(est_l1inl2mean, c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
               
               table <- matrix(NA, nrow = nrow(l1_inter_matrix[[i]][[1]]) * nrow(l2_matrix[[j]]), ncol = 6)
               for (k1 in 1:nrow(l1_inter_matrix[[i]][[1]])){
                 temp <- ((k1-1) * nrow(l2_matrix[[j]]) + 1):((k1-1) * nrow(l2_matrix[[j]]) + nrow(l2_matrix[[j]]))
-                table[temp, 4] <- round(means[k1,], digits = 5)
-                table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-                table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+                table[temp, 4] <- round(means[k1,], digits = 4)
+                table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+                table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
                 table[temp, 1] <- attr(l1_inter_matrix[[i]][[1]],'levels')[k1,][1]
                 table[temp, 2] <- attr(l1_inter_matrix[[i]][[1]],'levels')[k1,][2]
                 table[temp, 3] <- attr(l2_matrix[[j]],'levels')
               }
-              colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]] - 1], attr(Z_classes, 'names')[l2_factors[j]], 'median', '2.5%', '97.5%')
+              colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]] - 1], attr(Z_classes, 'names')[l2_factors[j]], 'mean', '2.5%', '97.5%')
               rownames(table) <- rep('', nrow(table))
               cat('\n')
               print(as.table(table))
+              sol_tables[['Table of means for interactions between level 1 interactions and level 2 factors: \n']] <- as.table(table)
             }
           }
         }
@@ -232,17 +239,18 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           est_l2inmean <- est_l2inmean + n_c*est_samples[[n_c]]
         }
-        means <- apply(est_l2inmean, 1, median)
+        means <- apply(est_l2inmean, 1, mean)
         quantile_025 <- apply(est_l2inmean, 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
         quantile_975 <- apply(est_l2inmean, 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
         table <- cbind(attr(l2_inter_matrix[[index]], 'levels'), 
-                       matrix(round(means, digits = 5), ncol = 1), 
-                       matrix(pmin(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), ncol = 1), 
-                       matrix(pmax(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), ncol = 1))
-        colnames(table) <- c(attr(Z_classes, 'names')[l2_interactions[[i]]], 'median', '2.5%', '97.5%')
+                       matrix(round(means, digits = 4), ncol = 1), 
+                       matrix(pmin(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), ncol = 1), 
+                       matrix(pmax(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), ncol = 1))
+        colnames(table) <- c(attr(Z_classes, 'names')[l2_interactions[[i]]], 'mean', '2.5%', '97.5%')
         rownames(table) <- rep('', nrow(table))
         cat('\n')
         print(as.table(table))
+        sol_tables[['Table of means for interactions at level 2: \n']] <- as.table(table)
         
         # print the interaction between this interaction and level 1 factors if there exists
         if (length(X_classes) != 0){
@@ -257,22 +265,23 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
               for (n_c in 1: n_choice){
                 est_l2inl1mean<- est_l2inl1mean  + n_c*est_samples[[n_c]]
               }
-              means <- apply(est_l2inl1mean, c(1,2), median)
+              means <- apply(est_l2inl1mean, c(1,2), mean)
               quantile_025 <- apply(est_l2inl1mean, c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
               quantile_975 <- apply(est_l2inl1mean, c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
               table <- matrix(NA, nrow = nrow(l1_matrix[[j]][[1]]) * nrow(l2_inter_matrix[[index]]), ncol = 6)
               for (k1 in 1:nrow(l1_matrix[[j]][[1]])){
                 temp <- ((k1-1) * nrow(l2_inter_matrix[[index]]) + 1):((k1-1) * nrow(l2_inter_matrix[[index]]) + nrow(l2_inter_matrix[[index]]))
-                table[temp, 4] <- round(means[k1,], digits = 5)
-                table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-                table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+                table[temp, 4] <- round(means[k1,], digits = 4)
+                table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+                table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
                 table[temp, 1] <- attr(l1_matrix[[j]][[1]],'levels')[k1]
                 table[temp, 2:3] <- attr(l2_inter_matrix[[i]],'levels')
               }
-              colnames(table) <- c(attr(X_classes, 'names')[l1_factors[[j]]], attr(Z_classes, 'names')[l2_interactions[[i]]], 'median', '2.5%', '97.5%')
+              colnames(table) <- c(attr(X_classes, 'names')[l1_factors[[j]]], attr(Z_classes, 'names')[l2_interactions[[i]]], 'mean', '2.5%', '97.5%')
               rownames(table) <- rep('', nrow(table))
               cat('\n')
               print(as.table(table))
+              sol_tables[['Table of means for interactions between level 2 interactions and level 1 factors: \n']] <- as.table(table)
             }
           }
         }
@@ -289,6 +298,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
   # Grand mean
   cat('\n')
   cat('Grand mean: \n')
+  sol_tables[['Grand mean(each response): \n']] <- list()
   l1_v <- list()
   for (n_c in 1:n_choice){
     temp <- matrix(rep(0, num_l1), nrow = 1)
@@ -301,8 +311,10 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
   for (n_c in 1:n_choice){
     cat('\n')
     cat('Choice:',n_c,'\n')
-    cat(round(mean(gmean[[n_c]]), digits = 5), '\n')
-    print(as.table(matrix(round(quantile(gmean[[n_c]], probs = c(0.025, 0.975)), digits = 5), nrow = 1, ncol = 2, dimnames = list('',c('2.5%','97.5%')))))
+    cat(round(mean(gmean[[n_c]]), digits = 4), '\n')
+    temp_title <- paste('Choice: ',n_c, sep ="")
+    sol_tables[['Grand mean(each response): \n']][[temp_title]] <- as.table(matrix(round(quantile(gmean[[n_c]], probs = c(0.025, 0.975)), digits = 4), nrow = 1, ncol = 2, dimnames = list('',c('2.5%','97.5%'))))
+    print(sol_tables[['Grand mean(each response): \n']][[temp_title]])
   }
   
   # means of main effect in level 1 and 2 
@@ -311,6 +323,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
     if (length(l1_factors) != 0){
       cat('\n')
       cat('Means for factors at level 1: \n')
+      sol_tables[['Means for factors at level 1: \n']] <- list()
       l1_matrix <- list()
       #l2_v <- matrix(c(1, rep(0, num_l2 - 1)), nrow = 1) # only look at the intercept in level 2
       for (i in 1:length(l1_factors)){
@@ -321,19 +334,21 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           cat('\n')
           cat('Choice:',n_c,'\n')
-          means <- apply(est_samples[[n_c]], 1, median)
+          means <- apply(est_samples[[n_c]], 1, mean)
           quantile_025 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
           quantile_975 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
           table <- matrix(NA, nrow = length(means), ncol = 4)
           table[, 2] <- means
           table[, 3] <- pmin(quantile_025, quantile_975)
           table[, 4] <- pmax(quantile_025, quantile_975)
-          table <- round(table, digits = 5)
+          table <- round(table, digits = 4)
           table[, 1] <- attr(l1_matrix[[i]][[1]],'levels')
-          colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], 'median', '2.5%', '97.5%')
+          colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], 'mean', '2.5%', '97.5%')
           rownames(table) <- rep('', nrow(table))
           cat('\n')
           print(as.table(table))
+          temp_title <- paste('Choice: ',n_c, sep ="")
+          sol_tables[['Means for factors at level 1: \n']][[temp_title]] <- as.table(table)
         }
       }
     }
@@ -344,6 +359,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
     if (length(l2_factors) != 0){
       cat('\n')
       cat('Means for factors at level 2: \n')
+      sol_tables[['Means for factors at level 2: \n']] <- list()
       l2_matrix <- list()
       for (i in 1:length(l2_factors)){
         l2_matrix[[i]] <- effect.matrix.factor(l2_values[[l2_factors[i]]], Z_assign, l2_factors[i], numeric_index_in_Z)
@@ -352,19 +368,21 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           cat('\n')
           cat('Choice:',n_c,'\n')
-          means <- apply(est_samples[[n_c]], 1, median)
+          means <- apply(est_samples[[n_c]], 1, mean)
           quantile_025 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
           quantile_975 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
           table <- matrix(NA, nrow = length(means), ncol = 4)
           table[, 2] <- means
           table[, 3] <- pmin(quantile_025, quantile_975)
           table[, 4] <- pmax(quantile_025, quantile_975)
-          table <- round(table, digits = 5)
+          table <- round(table, digits = 4)
           table[, 1] <- attr(l2_matrix[[i]],'levels')
-          colnames(table) <- c(attr(Z_classes, 'names')[l2_factors[i]], 'median', '2.5%', '97.5%')
+          colnames(table) <- c(attr(Z_classes, 'names')[l2_factors[i]], 'mean', '2.5%', '97.5%')
           rownames(table) <- rep('', nrow(table))
           cat('\n')
           print(as.table(table))
+          temp_title <- paste('Choice: ',n_c, sep ="")
+          sol_tables[['Means for factors at level 2: \n']][[temp_title]] <- as.table(table)
         }
       }
     }
@@ -375,6 +393,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
     if (length(l1_factors) != 0 && length(l2_factors) != 0){
       cat('\n')
       cat('Means for interactions between level 1 and level 2 factors: \n')
+      sol_tables[['Means for interactions between level 1 and level 2 factors: \n']] <- list()
       for (i in 1:length(l1_factors)){
         for (j in 1:length(l2_factors)){
           #means <- l1_matrix[[i]] %*% est_matrix_mean %*% t(l2_matrix[[j]])
@@ -385,22 +404,24 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
           for (n_c in 1: n_choice){
             cat('\n')
             cat('Choice:',n_c,'\n')
-            means <- apply(est_samples[[n_c]], c(1,2), median)
+            means <- apply(est_samples[[n_c]], c(1,2), mean)
             quantile_025 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
             quantile_975 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
             table <- matrix(NA, nrow = nrow(l1_matrix[[i]][[1]]) * nrow(l2_matrix[[j]]), ncol = 5)
             for (k1 in 1:nrow(l1_matrix[[i]][[1]])){
               temp <- ((k1-1) * nrow(l2_matrix[[j]]) + 1):((k1-1) * nrow(l2_matrix[[j]]) + nrow(l2_matrix[[j]]))
-              table[temp, 3] <- round(means[k1,], digits = 5)
-              table[temp, 4] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-              table[temp, 5] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+              table[temp, 3] <- round(means[k1,], digits = 4)
+              table[temp, 4] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+              table[temp, 5] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
               table[temp, 1] <- rep(attr(l1_matrix[[i]][[1]],'levels')[k1], nrow(l2_matrix[[j]]))
               table[temp, 2] <- attr(l2_matrix[[j]],'levels')
             }
-            colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], attr(Z_classes, 'names')[l2_factors[j]], 'median', '2.5%', '97.5%')
+            colnames(table) <- c(attr(X_classes, 'names')[l1_factors[i]], attr(Z_classes, 'names')[l2_factors[j]], 'mean', '2.5%', '97.5%')
             rownames(table) <- rep('', nrow(table))
             cat('\n')
-            print(as.table(table))  
+            print(as.table(table))
+            temp_title <- paste('Choice: ',n_c, sep ="")
+            sol_tables[['Means for interactions between level 1 and level 2 factors: \n']][[temp_title]] <- as.table(table)
           }
         }
       }          
@@ -411,6 +432,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
   if (length(l1_interactions) > 0){
     cat('\n')
     cat('Means for interactions at level 1: \n')
+    sol_tables[['Means for interactions at level 1: \n']] <- list()
     l1_inter_matrix <- list()
     index <- 1
     for (i in 1:length(l1_interactions)){
@@ -427,18 +449,19 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           cat('\n')
           cat('Choice:',n_c,'\n')
-          means <- apply(est_samples[[n_c]], 1, median)
+          means <- apply(est_samples[[n_c]], 1, mean)
           quantile_025 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
           quantile_975 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
           table <- cbind(attr(l1_inter_matrix[[index]][[1]], 'levels'), 
-                         round(means, digits = 5), 
-                         pmin(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), 
-                         pmax(round(quantile_025, digits = 5), round(quantile_975, digits = 5)))
-          colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]]], 'median', '2.5%', '97.5%')
+                         round(means, digits = 4), 
+                         pmin(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), 
+                         pmax(round(quantile_025, digits = 4), round(quantile_975, digits = 4)))
+          colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]]], 'mean', '2.5%', '97.5%')
           rownames(table) <- rep('', nrow(table))
-          
           cat('\n')
           print(as.table(table))
+          temp_title <- paste('Choice: ', n_c, sep ="")
+          sol_tables[['Means for interactions at level 1: \n']][[temp_title]] <- as.table(table)
         }
         
         # print the interaction between this interaction and level 2 factors if there exists
@@ -447,6 +470,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
           if (length(l2_factors) != 0){
             cat('\n')
             cat('Means for interactions between level 1 interactions and level 2 factors: \n')
+            sol_tables[['Means for interactions between level 1 interactions and level 2 factors: \n']] <- list()
             for (j in 1:length(l2_factors)){
               #means <- l1_inter_matrix[[index]] %*% est_matrix_mean %*% t(l2_matrix[[j]])
               #quantile_025 <- l1_inter_matrix[[index]] %*% est_matrix_025 %*% t(l2_matrix[[j]])
@@ -456,24 +480,26 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
               for (n_c in 1: n_choice){
                 cat('\n')
                 cat('Choice:',n_c,'\n')
-                means <- apply(est_samples[[n_c]], c(1,2), median)
+                means <- apply(est_samples[[n_c]], c(1,2), mean)
                 quantile_025 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
                 quantile_975 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
                 
                 table <- matrix(NA, nrow = nrow(l1_inter_matrix[[i]][[1]]) * nrow(l2_matrix[[j]]), ncol = 6)
                 for (k1 in 1:nrow(l1_inter_matrix[[i]][[1]])){
                   temp <- ((k1-1) * nrow(l2_matrix[[j]]) + 1):((k1-1) * nrow(l2_matrix[[j]]) + nrow(l2_matrix[[j]]))
-                  table[temp, 4] <- round(means[k1,], digits = 5)
-                  table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-                  table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+                  table[temp, 4] <- round(means[k1,], digits = 4)
+                  table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+                  table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
                   table[temp, 1] <- attr(l1_inter_matrix[[i]][[1]],'levels')[k1,][1]
                   table[temp, 2] <- attr(l1_inter_matrix[[i]][[1]],'levels')[k1,][2]
                   table[temp, 3] <- attr(l2_matrix[[j]],'levels')
                 }
-                colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]] - 1], attr(Z_classes, 'names')[l2_factors[j]], 'median', '2.5%', '97.5%')
+                colnames(table) <- c(attr(X_classes, 'names')[l1_interactions[[i]] - 1], attr(Z_classes, 'names')[l2_factors[j]], 'mean', '2.5%', '97.5%')
                 rownames(table) <- rep('', nrow(table))
                 cat('\n')
                 print(as.table(table))
+                temp_title <- paste('Choice: ', n_c, sep ="")
+                sol_tables[['Means for interactions between level 1 interactions and level 2 factors: \n']][[temp_title]] <- as.table(table)
               }
             }
           }
@@ -486,6 +512,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
   if (length(l2_interactions) > 0){
     cat('\n')
     cat('Means for interactions at level 2: \n')
+    sol_tables[['Means for interactions at level 2: \n']] <- list()
     l2_inter_matrix <- list()
     index <- 1
     for (i in 1:length(l2_interactions)){
@@ -502,17 +529,19 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
         for (n_c in 1: n_choice){
           cat('\n')
           cat('Choice:',n_c,'\n')
-          means <- apply(est_samples[[n_c]], 1, median)
+          means <- apply(est_samples[[n_c]], 1, mean)
           quantile_025 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.025, type = 3, na.rm = FALSE)
           quantile_975 <- apply(est_samples[[n_c]], 1, quantile, probs = 0.975, type = 3, na.rm = FALSE)
           table <- cbind(attr(l2_inter_matrix[[index]], 'levels'), 
-                         matrix(round(means, digits = 5), ncol = 1), 
-                         matrix(pmin(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), ncol = 1), 
-                         matrix(pmax(round(quantile_025, digits = 5), round(quantile_975, digits = 5)), ncol = 1))
-          colnames(table) <- c(attr(Z_classes, 'names')[l2_interactions[[i]]], 'median', '2.5%', '97.5%')
+                         matrix(round(means, digits = 4), ncol = 1), 
+                         matrix(pmin(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), ncol = 1), 
+                         matrix(pmax(round(quantile_025, digits = 4), round(quantile_975, digits = 4)), ncol = 1))
+          colnames(table) <- c(attr(Z_classes, 'names')[l2_interactions[[i]]], 'mean', '2.5%', '97.5%')
           rownames(table) <- rep('', nrow(table))
           cat('\n')
           print(as.table(table))
+          temp_title <- paste('Choice: ', n_c, sep ="")
+          sol_tables[['Means for interactions at level 2: \n']][[temp_title]] <- as.table(table)
         }
         
         # print the interaction between this interaction and level 1 factors if there exists
@@ -521,6 +550,7 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
           if (length(l1_factors) != 0){
             cat('\n')
             cat('Means for interactions between level 2 interactions and level 1 factors: \n')
+            sol_tables[['Means for interactions between level 2 interactions and level 1 factors: \n']] <- list()
             for (j in 1:length(l1_factors)){
               #means <- l1_matrix[[j]] %*% est_matrix_mean %*% t(l2_inter_matrix[[index]])
               #quantile_025 <- l1_matrix[[j]] %*% est_matrix_025 %*% t(l2_inter_matrix[[index]])
@@ -530,22 +560,24 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
               for (n_c in 1: n_choice){
                 cat('\n')
                 cat('Choice:',n_c,'\n')
-                means <- apply(est_samples[[n_c]], c(1,2), median)
+                means <- apply(est_samples[[n_c]], c(1,2), mean)
                 quantile_025 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.025, type = 3, na.rm = FALSE)
                 quantile_975 <- apply(est_samples[[n_c]], c(1,2), quantile, probs = 0.975, type = 3, na.rm = FALSE)
                 table <- matrix(NA, nrow = nrow(l1_matrix[[j]][[1]]) * nrow(l2_inter_matrix[[index]]), ncol = 6)
                 for (k1 in 1:nrow(l1_matrix[[j]][[1]])){
                   temp <- ((k1-1) * nrow(l2_inter_matrix[[index]]) + 1):((k1-1) * nrow(l2_inter_matrix[[index]]) + nrow(l2_inter_matrix[[index]]))
-                  table[temp, 4] <- round(means[k1,], digits = 5)
-                  table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
-                  table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 5), round(quantile_975[k1,], digits = 5))
+                  table[temp, 4] <- round(means[k1,], digits = 4)
+                  table[temp, 5] <- pmin(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
+                  table[temp, 6] <- pmax(round(quantile_025[k1,], digits = 4), round(quantile_975[k1,], digits = 4))
                   table[temp, 1] <- attr(l1_matrix[[j]][[1]],'levels')[k1]
                   table[temp, 2:3] <- attr(l2_inter_matrix[[i]],'levels')
                 }
-                colnames(table) <- c(attr(X_classes, 'names')[l1_factors[[j]]], attr(Z_classes, 'names')[l2_interactions[[i]]], 'median', '2.5%', '97.5%')
+                colnames(table) <- c(attr(X_classes, 'names')[l1_factors[[j]]], attr(Z_classes, 'names')[l2_interactions[[i]]], 'mean', '2.5%', '97.5%')
                 rownames(table) <- rep('', nrow(table))
                 cat('\n')
                 print(as.table(table))
+                temp_title <- paste('Choice: ', n_c, sep ="")
+                sol_tables[['Means for interactions between level 2 interactions and level 1 factors: \n']][[temp_title]] <- as.table(table)
               }
             }
           }
@@ -555,5 +587,5 @@ function (coeff_table, n_choice, samples_l2_param, X_names, X_assign = array(dim
     }
     
   }
-  
+  return(sol_tables)
 }
